@@ -6,21 +6,21 @@
 #' @export download_graph
 #' @importFrom utils download.file untar read.table
 #' @importFrom Matrix readMM
-#' @param graphname Name of the graph to download.
+#' @param matrixname Name of the graph to download.
 #' @param groupname Name of the group that provides the graph.
-#' @return \code{graphname} a list contening the sparse matrix \code{sA}, \code{xy} coordinates (if any), \code{dim} the number of rows, columns and numerically nonzero elements  and \code{info}, the path to a plain txt file containing information associated with \code{sA} (accessible for example via \code{file.show(graphname$info)}).
+#' @return \code{matrixname} a list contening the sparse matrix \code{sA}, \code{xy} coordinates (if any), \code{dim} the number of rows, columns and numerically nonzero elements  and \code{info}, the path to a plain txt file containing information associated with \code{sA} (accessible for example via \code{file.show(matrixname$info)}).
 #' @references
 #' Davis, T. A., & Hu, Y. (2011). The University of Florida sparse matrix collection. ACM Transactions on Mathematical Software (TOMS), 38(1), 1-25.
 #' @examples
-#' graphname <- "grid1"
+#' matrixname <- "grid1"
 #' groupname <- "AG-Monien"
-#' download_graph(graphname,groupname)
+#' download_graph(matrixname,groupname)
 #' file.show(grid1$info)
 
-download_graph <- function(graphname, groupname) {
+download_graph <- function(matrixname, groupname) {
     url <- paste("https://sparse.tamu.edu/MM/",
                  groupname,"/",
-                 graphname,".tar.gz",sep = "")
+                 matrixname,".tar.gz",sep = "")
 
     temp <- tempfile()
     tempd <- tempdir()
@@ -29,22 +29,22 @@ download_graph <- function(graphname, groupname) {
 
     if (Sys.info()['sysname']=="Windows"){
       tempp <- paste(tempd,
-                     paste(graphname,"\\",sep=""),
+                     paste(matrixname,"\\",sep=""),
                      sep ="\\")
     } else{
       tempp <- file.path(tempd,
-                         paste(graphname,"/",sep=""))
+                         paste(matrixname,"/",sep=""))
     }
 
     temppath <- paste(tempp,
-                      graphname,".mtx",sep="")
+                      matrixname,".mtx",sep="")
 
     tmp <- readLines(temppath)
     nskip <- length(grep("%",tmp))+1
 
     #store graph descrition in tmp folder
     graphdesc <- paste(tempp,
-                        graphname,sep="")
+                        matrixname,sep="")
 
     # df <- read.table(temppath,
     #                  comment.char = "%",
@@ -78,7 +78,7 @@ download_graph <- function(graphname, groupname) {
       writeLines(tmp[1:(nskip)],
                  graphdesc)
       temppathc <- paste(tempp,
-                         graphname,"_coord.mtx",sep="")
+                         matrixname,"_coord.mtx",sep="")
 
       tmpc <- readLines(temppathc)
       nskipc <- length(grep("%",tmpc))+1
@@ -94,7 +94,7 @@ download_graph <- function(graphname, groupname) {
       {
         colnames(dfc) <- c("x", "y")
       }
-      return(assign(graphname,
+      return(assign(matrixname,
                     list("sA"=m,
                          "xy"=dfc,
                          "dim"=graphdim,
@@ -104,7 +104,7 @@ download_graph <- function(graphname, groupname) {
     else {
       writeLines(tmp[1:(nskip)],
                  graphdesc)
-      return(assign(graphname,
+      return(assign(matrixname,
                     list("sA"=m,
                          "dim"=graphdim,
                          "info"=graphdesc),
